ipython: Interactive computing environment with an enhanced interactive Python shell
====================================================================================

Description
-----------

Interactive computing environment with an enhanced interactive Python shell

From the IPython website:

IPython is a multiplatform, Free Software project (BSD licensed) that
offers:

-  An enhanced Python shell designed for efficient interactive
   work. It includes many enhancements over the default Python shell,
   including the ability for controlling interactively all major GUI
   toolkits in a non-blocking manner.

-  A library to build customized interactive environments using Python
   as the basic language (but with the possibility of having extended
   or alternate syntaxes).

-  A system for interactive distributed and parallel computing (this is
   part of IPython's new development).

License
-------

BSD


Upstream Contact
----------------

http://ipython.org
